@@ -12,6 +12,7 @@ except ImportError:
     pass
 
 import argparse
+import traceback
 from typing import Any
 from uuid import uuid4
 from pprint import pprint
@@ -130,7 +131,7 @@ def build_llama_cpp_cmd(device: tuple[int, int, int],
         ])
     elif BACKEND == 'hipblas':
         pass
-    elif BACKEND == 'clblas':
+    elif BACKEND == 'cublas':
         pass
     else:
         raise ValueError(BACKEND)
@@ -324,8 +325,9 @@ async def run_prompt(device: tuple[int, int, int],
     print('!! stdout:')
     print(stdout)
     
-    # print('!! stderr:')
-    # print(stderr)
+    if not stdout:
+        print('!! stderr:')
+        print(stderr)
 
     if cm.expired:
         res = {
@@ -588,6 +590,7 @@ async def get_api_1_0_text_completion(request, id_: str):
 
             await task
     except ExceptionGroup as e:
+        traceback.print_exc()
         print('ExceptionGroup:', e)
 
         # find device
